@@ -1,7 +1,7 @@
 package Vimana::Command::Info;
 use warnings;
 use strict;
-use parent qw(App::CLI::Command);
+use base qw(App::CLI::Command);
 
 sub options {
     ();
@@ -12,11 +12,6 @@ sub run {
     my ( $self, $package ) = @_;
     my $index = Vimana->index;
     my $info = $index->find_package( $package );
-    unless ( $info->{script_id} ) {
-        warn "No script named $package. Trying $package.vim ..";
-        $info = $index->find_package( "$package.vim" );
-        die "Unknown script named $package" unless $info;
-    }
     require Vimana::VimOnline::ScriptPage;
 
     my $script_info = Vimana::VimOnline::ScriptPage->fetch( $info->{script_id} ) ;
