@@ -1,16 +1,18 @@
 package Vimana::Index;
 use warnings;
 use strict;
-use File::Path;
-use Vimana::Util;
-use Mouse;
 
-has cache =>
-    is => 'rw';
+use Cache::File;
+use Vimana::Logger;
+use base qw/Class::Accessor::Fast/;
+__PACKAGE__->mk_accessors( qw(cache) );
 
 sub init {
     my $self = shift;
-
+    $logger->debug("cache::file init");
+    my $cache = Vimana->cache;
+    $logger->debug("cache::file done");
+    $self->cache( $cache );
 }
 
 
@@ -26,13 +28,16 @@ sub find_package_like {
     return undef;
 }
 
+use Vimana::Util;
 sub find_package {
     my ($self, $findname ) = @_;
     my $index = $self->read_index();
     my $cname = canonical_script_name( $findname );
-    return defined $index->{ $cname } ? $index->{ $cname } : undef;
+    $logger->info( "Canonical name: $cname" );
+    return defined $index->{ $cname }  ? $index->{ $cname } : undef;
 }
 
+use File::Path;
 
 sub index_file {
     my $dir = $ENV{HOME} . "/.vimana";
