@@ -56,8 +56,8 @@ sub download {
 
     unlink $self->file if -e $self->file;
 
-    print "Save to " . $self->file . "\n";
-    open FH,">",$self->file or die $@;
+    print "Saving file to " . $self->file . "\n";
+    open FH, ">", $self->file or die $@;
     print FH $file_content;
     close FH;
 
