@@ -1,11 +1,10 @@
 package Vimana::PortInstall;
 use warnings;
 use strict;
-use Moose;
 use Vimana::Util;
 use Vimana::Logger;
-has package => ( is => 'rw' , isa => 'Vimana::PackageFile' );
-
+use base qw/Class::Accessor::Fast/;
+__PACKAGE__->mk_accessors( qw(package) );
 
 sub run {
     my $self = shift;
